##  Creating a Free Draw Diagram from a Template Preview
You can create regular, fully editable free draw diagrams from templates. Once created, they behave independently of the template with no live link. Subsequent template changes don't update the diagram, and the diagram behaves like any other diagram in your workspace.
  1. Open a template from Diagram Templates.
  2. Select one or more fact sheets from the drop-down list, and optionally, apply a view.
  3. Choose Save as Diagram.
A new free draw diagram is created and opens in the diagram editor.
Free Draw Diagram Based on a Diagram Template
![Diagram editor with a template-based diagram and shape palette on the left.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio0a73a67425ae4913912ed1b8b80398dc_LowRes.png)


You can now modify the diagram freely. Rearrange shapes and adjust the layout, add or remove elements, and edit labels and annotations.
Learn more in [Free Draw Diagrams](https://help.sap.com/docs/leanix/ea/free-draw?locale=en-US&state=PRODUCTION&version=CLOUD).
**Tip**
Use a consistent naming pattern so generated diagrams are easy to find, for example, [Template Name] – [Fact Sheet Name] – Diagram.
